SwipeableWidget class

A Widget that have the ability to detect swipe on itself with customizable variables.

Inheritance

Constructors

SwipeableWidget({Key? key, required Widget child, required double height, required VoidCallback onSwipeCallback, required dynamic onSwipeStartcallback(bool, double), required double screenSize, double? swipePercentageNeeded = 0.75})

Properties

child → Widget
The Widget on which we want to detect the swipe movement.
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
The Height of the widget that will be drawn, required.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSwipeCallback → VoidCallback
The VoidCallback that will be called once a swipe with certain percentage is detected.
final
onSwipeStartcallback → dynamic Function(bool, double)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenSize → double
final
swipePercentageNeeded → double?
The decimal percentage of swiping in order for the callbacks to get called, defaults to 0.75 (75%) of the total width of the children.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _SwipeableWidgetState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited